==> org.eclipse.equinox.p2.touchpoint.eclipse.source_2.1.300.v20150423-1455.jar: org/eclipse/equinox/internal/p2/touchpoint/eclipse/actions/ActionConstants.java <==
/*******************************************************************************
 * Copyright (c) 2008, 2011 IBM Corporation and others. All rights reserved. This
 * program and the accompanying materials are made available under the terms of
 * the Eclipse Public License v1.0 which accompanies this distribution, and is
 * available at http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: IBM Corporation - initial API and implementation
 ******************************************************************************/
package org.eclipse.equinox.internal.p2.touchpoint.eclipse.actions;

public class ActionConstants {

	public static final String PARM_AGENT = "agent"; //$NON-NLS-1$
	public static final String PARM_AT_ARTIFACT = "@artifact"; //$NON-NLS-1$
	public static final String PARM_ARTIFACT_FILES = "artifactFiles"; //$NON-NLS-1$
	public static final String PARM_ARTIFACT_REQUESTS = "artifactRequests"; //$NON-NLS-1$
	public static final String PARM_BUNDLE = "bundle"; //$NON-NLS-1$
	public static final String PARM_FEATURE = "feature"; //$NON-NLS-1$
	public static final String PARM_FEATURE_ID = "featureId"; //$NON-NLS-1$
	public static final String PARM_FEATURE_VERSION = "featureVersion"; //$NON-NLS-1$
	public static final String PARM_IGNORE = "@ignore"; //$NON-NLS-1$
	public static final String PARM_IU = "iu"; //$NON-NLS-1$
	public static final String PARM_JVM = "jvm"; //$NON-NLS-1$
	public static final String PARM_JVM_ARG = "jvmArg"; //$NON-NLS-1$
	public static final String PARM_PREVIOUS_START_LEVEL = "previousStartLevel"; //$NON-NLS-1$
	public static final String PARM_PREVIOUS_STARTED = "previousStarted"; //$NON-NLS-1$
	public static final String PARM_PREVIOUS_VALUE = "previousValue"; //$NON-NLS-1$
	public static final String PARM_PROFILE = "profile"; //$NON-NLS-1$
	public static final String PARM_PROGRAM_ARG = "programArg"; //$NON-NLS-1$
	public static final String PARM_PROGRAM_ARG_VALUE = "programArgValue"; //$NON-NLS-1$
	public static final String PARM_PROP_NAME = "propName"; //$NON-NLS-1$
	public static final String PARM_PROP_VALUE = "propValue"; //$NON-NLS-1$
	public static final String PARM_START_LEVEL = "startLevel"; //$NON-NLS-1$
	public static final String PARM_STARTED = "started"; //$NON-NLS-1$
	public static final String PARM_DEFAULT_VALUE = "default"; //$NON-NLS-1$
	public static final String PARM_LAUNCHERNAME = "name"; //$NON-NLS-1$
	public static final String PARM_PATH = "path"; //$NON-NLS-1$
	public static final String PARM_TARGET_DIR = "targetDir"; //$NON-NLS-1$
	public static final String PARM_LINK_NAME = "linkName"; //$NON-NLS-1$
	public static final String PARM_LINK_FORCE = "force"; //$NON-NLS-1$
	public static final String PARM_LINK_TARGET = "linkTarget"; //$NON-NLS-1$
	public static final String PARM_TARGET_FILE = "targetFile"; //$NON-NLS-1$
	public static final String PARM_PERMISSIONS = "permissions"; //$NON-NLS-1$
	public static final String PARM_PROFILE_DATA_DIRECTORY = "profileDataDirectory"; //$NON-NLS-1$

	public static final String PARM_REPOSITORY_LOCATION = "location"; //$NON-NLS-1$
	public static final String PARM_REPOSITORY_TYPE = "type"; //$NON-NLS-1$
	public static final String PARM_REPOSITORY_ENABLEMENT = "enabled"; //$NON-NLS-1$
	public static final String PARM_REPOSITORY_NICKNAME = "name"; //$NON-NLS-1$
	public static final Object PARM_OPTIONS = "options"; //$NON-NLS-1$
}

==> org.eclipse.equinox.p2.touchpoint.eclipse.source_2.2.0.v20180302-1057.jar: org/eclipse/equinox/internal/p2/touchpoint/eclipse/actions/ActionConstants.java <==
/*******************************************************************************
 * Copyright (c) 2008, 2017 IBM Corporation and others. All rights reserved. This
 * program and the accompanying materials are made available under the terms of
 * the Eclipse Public License v1.0 which accompanies this distribution, and is
 * available at http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: IBM Corporation - initial API and implementation
 ******************************************************************************/
package org.eclipse.equinox.internal.p2.touchpoint.eclipse.actions;

public class ActionConstants {

	public static final String PARM_AGENT = "agent"; //$NON-NLS-1$
	public static final String PARM_AT_ARTIFACT = "@artifact"; //$NON-NLS-1$
	public static final String PARM_ARTIFACT_FILES = "artifactFiles"; //$NON-NLS-1$
	public static final String PARM_ARTIFACT_REQUESTS = "artifactRequests"; //$NON-NLS-1$
	public static final String PARM_BUNDLE = "bundle"; //$NON-NLS-1$
	public static final String PARM_FEATURE = "feature"; //$NON-NLS-1$
	public static final String PARM_FEATURE_ID = "featureId"; //$NON-NLS-1$
	public static final String PARM_FEATURE_VERSION = "featureVersion"; //$NON-NLS-1$
	public static final String PARM_IGNORE = "@ignore"; //$NON-NLS-1$
	public static final String PARM_IU = "iu"; //$NON-NLS-1$
	public static final String PARM_JVM = "jvm"; //$NON-NLS-1$
	public static final String PARM_JVM_ARG = "jvmArg"; //$NON-NLS-1$
	public static final String PARM_PREVIOUS_START_LEVEL = "previousStartLevel"; //$NON-NLS-1$
	public static final String PARM_PREVIOUS_STARTED = "previousStarted"; //$NON-NLS-1$
	public static final String PARM_PREVIOUS_VALUE = "previousValue"; //$NON-NLS-1$
	public static final String PARM_PROFILE = "profile"; //$NON-NLS-1$
	public static final String PARM_PROGRAM_ARG = "programArg"; //$NON-NLS-1$
	public static final String PARM_PROGRAM_ARG_VALUE = "programArgValue"; //$NON-NLS-1$
	public static final String PARM_PROP_NAME = "propName"; //$NON-NLS-1$
	public static final String PARM_PROP_VALUE = "propValue"; //$NON-NLS-1$
	public static final String PARM_START_LEVEL = "startLevel"; //$NON-NLS-1$
	public static final String PARM_STARTED = "started"; //$NON-NLS-1$
	public static final String PARM_DEFAULT_VALUE = "default"; //$NON-NLS-1$
	public static final String PARM_LAUNCHERNAME = "name"; //$NON-NLS-1$
	public static final String PARM_PATH = "path"; //$NON-NLS-1$
	public static final String PARM_TARGET_DIR = "targetDir"; //$NON-NLS-1$
	public static final String PARM_LINK_NAME = "linkName"; //$NON-NLS-1$
	public static final String PARM_LINK_FORCE = "force"; //$NON-NLS-1$
	public static final String PARM_LINK_TARGET = "linkTarget"; //$NON-NLS-1$
	public static final String PARM_TARGET_FILE = "targetFile"; //$NON-NLS-1$
	public static final String PARM_PERMISSIONS = "permissions"; //$NON-NLS-1$
	public static final String PARM_PROFILE_DATA_DIRECTORY = "profileDataDirectory"; //$NON-NLS-1$

	public static final String PARM_REPOSITORY_LOCATION = "location"; //$NON-NLS-1$
	public static final String PARM_REPOSITORY_TYPE = "type"; //$NON-NLS-1$
	public static final String PARM_REPOSITORY_ENABLEMENT = "enabled"; //$NON-NLS-1$
	public static final String PARM_REPOSITORY_NICKNAME = "name"; //$NON-NLS-1$
	public static final String PARM_OPTIONS = "options"; //$NON-NLS-1$
}
